@@ -173,9 +173,8 @@ class DicomReaderWriter:
         self.arg_max = arg_max
         self.rewrite_RT_file = rewrite_RT_file
         self.dose_handles = []
-        if template_dir is None:
-            package_name = __package__.split('.')[-1]
-            template_dir = os.path.join(__file__[:__file__.index(package_name)],package_name,'template_RS.dcm')
+        if template_dir is None or not os.path.exists(template_dir):
+            template_dir = os.path.join(os.path.split(__file__)[0], 'template_RS.dcm')
         self.template_dir = template_dir
         self.template = True
         self.delete_previous_rois = delete_previous_rois
